==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/managephones/popupEdit.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
</head>
<?php 
require('../assets/inc/ldapConnect.php');
require('load.php');
$wanIP = (@file_get_contents("http://splicepbx.uk/ip.php")) ? @file_get_contents("http://splicepbx.uk/ip.php") : @file_get_contents("http://ipecho.net/plain") ;

if ($selectedType === '2'){
	$sslserver = $pcsserver = $showUpgrade = NULL;
	$sr = @ldap_read($ds,"cn=ssl,cn=system","objectclass=updateserver"); 
	if ($sr) { $info = ldap_get_entries($ds,$sr); $sslserver = $info[0]['url'][0]; }
	
	$sr = @ldap_read($ds,"cn=pcs,cn=system","objectclass=updateserver"); 
	if ($sr) { $info = ldap_get_entries($ds,$sr); $pcsserver = $info[0]['url'][0]; }
	
	if ($sslserver && $pcsserver) $showUpgrade = true;
}
?>
<body>
<!-- Element to pop up -->
<div style='background-color:#dddddd; border: 4px solid black; padding: 5px; height: 565px; width: 1015px;'>

<div id="wrapper">
        <ul id="tabs">
            <li class="active">Edit Phone</li>
			<?php  				
			if ($sipType == 'Yealink') 
				echo "<li>Provisioning</li>";
			?>

        </ul>
        <ul id="tab">
		<form id='popup'>
		<!-- first tab -->
            <li class="active">
                <h2><span id='FormIcon' class='icon-phone'></span> <span id='FormText'>Edit Phone: <?php echo "$selectedName - $sipType $typeofphone" ?></span></h2>
								
				<!-- #left -->
				<div class="colLeft">
				
				<!-- commonValues -->
					<div class='field'>
						<label class='grey' for="phoneName"><?php echo $phoneNameText ?></label>
						<input type='text' id='phoneName' name='phoneName' 
						<?php if ($sipType == 'Yealink') {
							echo "class='yealinkDevice' maxlength='12'"; 
							$phoneName = str_replace('SIP ','',$phoneName);
						}
						echo "value='$phoneName' $phoneNameState"; 
						?> 
						>
						<span class='information'><?php echo $phoneNameSpan ?></span>
					</div>
					
					<div class='field'>
						<label class='grey' for="description">Description</label>
						<input type='text' id='description' name='description' value='<?php echo $description ?>' >
						<span class='information'>PHONE DESCRIPTION</span>
					</div>
					
					<?php if ($sipType == 'Yealink') {
					echo "<div class='field'>
						<label class='grey' for='sipMACAddress'>Yealink Device MAC Address</label>
						<input type='text' id='sipMACAddress' name='sipMACAddress' value='$sipMACAddress' maxlength='12'>
						<span class='information'>YEALINK DEVICE MAC ADDRESS</span>
					</div>";
					}
					?>

				<!-- commonValues -->


				<!-- pcsPhone -->
				<?php if ($selectedType === '2') { ?>
					<div class='field'>
						<label class='grey' for="pcsSerial">Phone Serial Number</label>
						<input type='text' id='pcsSerial' name='pcsSerial' value='<?php echo $pcsSerial ?>' >
						<span class='information'>SPLICECOM PCS IP SERIAL NUMBER</span>
					</div>
				<?php } ?>
				<!-- pcsPhone -->
				
				
				<!-- potsPhone -->
				<?php if ($selectedType === '1') { ?>
					<div class='field'>
						<label class='grey' for="potCallerDisplayType">Caller Display Type</label>
						<select id='potCallerDisplayType' name='potCallerDisplayType'>
						<option value='0'  <?php if ($potCallerDisplayType === '0') echo 'selected' ?> >None</option>
						<option value='1'  <?php if ($potCallerDisplayType === '1') echo 'selected' ?> >Default</option>
						<option value='9'  <?php if ($potCallerDisplayType === '9') echo 'selected' ?> >Alarm</option>
						<option value='3'  <?php if ($potCallerDisplayType === '3') echo 'selected' ?> >Bell</option>
						<option value='2'  <?php if ($potCallerDisplayType === '2') echo 'selected' ?> >BT</option>
						<option value='5'  <?php if ($potCallerDisplayType === '5') echo 'selected' ?> >BT No Messages</option>
						<option value='4'  <?php if ($potCallerDisplayType === '4') echo 'selected' ?> >DTMF</option>
						<option value='15' <?php if ($potCallerDisplayType === '15') echo 'selected' ?> >Fax</option>
						<option value='7'  <?php if ($potCallerDisplayType === '7') echo 'selected' ?> >Fax Server</option>
						<option value='12' <?php if ($potCallerDisplayType === '12') echo 'selected' ?> >Lamp</option>
						<option value='8'  <?php if ($potCallerDisplayType === '8') echo 'selected' ?> >Interquartz</option>
						<option value='13' <?php if ($potCallerDisplayType === '13') echo 'selected' ?> >Pay Phone</option>
						<option value='10' <?php if ($potCallerDisplayType === '10') echo 'selected' ?> >PCS 10</option>
						<option value='11' <?php if ($potCallerDisplayType === '11') echo 'selected' ?> >PCS 10 Lamp</option>
						<option value='14' <?php if ($potCallerDisplayType === '14') echo 'selected' ?> >System Phone</option>
						<option value='6'  <?php if ($potCallerDisplayType === '6') echo 'selected' ?> >Trunk</option>
						<option value='16' <?php if ($potCallerDisplayType === '16') echo 'selected' ?> >BTD1K</option>
						<option value='17' <?php if ($potCallerDisplayType === '17') echo 'selected' ?> >DTMFR12</option>
						</select>
						<span class='information'>SPLICECOM POTS PORT CALLER DISPLAY TYPE</span>
					</div>
					<div class='field'>
						<label class='grey' for="potCallerDisplayLength">Caller Display Length</label>
						<input type='text' id='potCallerDisplayLength' name='potCallerDisplayLength' value='<?php echo $potCallerDisplayLength ?>'>
						<span class='information'>SPLICECOM POTS PORT CALLER DISPLAY LENGTH</span>
					</div>
				<?php } ?>
				<!-- potsPhone -->

				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
				
				<!-- pcsPhone -->
				<?php if ($selectedType === '2') { ?>
					<div class='field'>
						<label class='grey' for="pcsProductVersion">Device Product Version</label>
						<input type='text' id='pcsProductVersion' name='pcsProductVersion' value='<?php echo $productversion ?>' readonly>
						<span class='information'>SPLICECOM PCS IP PHONE PRODUCT VERSION</span>
					</div>					
					<div class='field'>
						<label class='grey' for="pcsPlc">Partner Login Code</label>
						<input type='text' id='pcsPlc' name='pcsPlc' value='<?php echo $pcsPlc ?>' >
						<span class='information'>SPLICECOM PCS IP PHONE PARTNER LOGIN CODE</span>
					</div>

					<?php 
					if ($showUpgrade) {
					?>
					<div class='field'>
						<label class='grey' for="pcsUpgrade">Upgrade Time</label>
						<input type='text' id='pcsUpgrade' name='pcsUpgrade' class='timepicker' value='' >
						<input type='hidden' id='pcsUpgradeTime' name='pcsUpgradeTime'value='<?php echo $pcsUpgrade ?>' disabled>
						<span class='information'>SPLICECOM PCS IP PHONE UPGRADE TIME</span>
					</div>										
					<?php
					}
					?>
					
					<div class='field'>
						<label class='grey' for="pcsExtnAnyWhere">Extension Anywhere</label>
						<input type='text' id='pcsExtnAnyWhere' name='pcsExtnAnyWhere' value='<?php echo $pcsExtnAnyWhere ?>' >
						<span class='information'>SPLICECOM PCS IP PHONE EXTENSION ANYWHERE</span>
					</div>										
				<?php } ?>
				<!-- pcsPhone -->
				
				
				
				<!-- potsPhone -->
				<?php if ($selectedType === '1') { ?>
				<div class='field'>
					<label class='grey' for="potPlc">Partner Login Code</label>
					<input type='text' id='potPlc' name='potPlc' value='<?php echo $potPlc ?>'>
					<span class='information'>SPLICECOM ANALOGUE PORT PARTNER LOGIN CODE</span>
				</div>		
				<div class='field'>
					<label class='grey' for="potsDTMF">Suppress DTMF</label>
					<div class='checkbox'><label for="potsDTMF"><div class="switch"><input type="checkbox" name='potsDTMF' id='potsDTMF' value="1" <?php if ($potsDTMF == "1") echo "checked" ?> />
					<div class="slider"></div></div></label></div>
					<span class='information'>SPLICECOM ANALOGUE PORT SUPPRESS DTMF</span>
				</div>					
				<div class='field'>
					<label class='grey' for="potExtnAnyWhere">Extension Anywhere</label>
					<input type='text' id='potExtnAnyWhere' name='potExtnAnyWhere' value='<?php echo $potExtnAnyWhere ?>'>
					<span class='information'>SPLICECOM ANALOGUE PORT EXTENSION ANYWHERE</span>
					</div>						
				<?php } ?>
				<!-- potsPhone -->
				
				<!-- genericPhone -->
				<?php if ($selectedType === '3') { ?>
					<div class='field'>
						<label class='grey' for="phoneProductVersion">Device Product Version</label>
						<input type='text' id='phoneProductVersion' name='phoneProductVersion' value='<?php echo $productversion ?>' readonly>
						<span class='information'>DEVICE PRODUCT VERSION</span>
					</div>					
					<div class='field'>
						<label class='grey' for="phoneIPAddress">Device IP Address</label>
						<input type='text' id='phoneIPAddress' name='phoneIPAddress' value='<?php echo $phoneIPAddress ?>'>
						<span class='information'>DEVICE IP ADDRESS</span>
					</div>
				<?php if ($sipType == "Yealink") { ?>
					<div class='field'>
						<label class='grey' for='siplicense'>SIP Phone Licence</label>
						<div class='checkbox'><label for="siplicense"><div class="switch"><input type="checkbox" name='siplicense' id='siplicense' value="1" <?php if ($siplicense == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>ENABLE SIP PHONE LICENCE</span>
					</div>	
				
				<?php
						}
					}
				?>
				<!-- genericPhone -->
				
					
				</div> 
				<!-- #right -->
			</li>	
			<!-- first tab -->
			
			<!-- Second tab -->
			<li>
                <h2><span id='FormIcon' class='icon-phone'></span> <span id='FormText'>Edit Phone: <?php echo "$selectedName - $sipType $typeofphone" ?></span></h2>
								
				<!-- #left -->
				<div class="colLeft">
				<div class='field'>
					<label class='grey' for='pnpvendor'>PnP Vendor</label>
					<input type='text' id='pnpvendor' name='pnpvendor' value='<?php echo $pnpvendor ?>' maxlength='64'>
					<span class='information'>PNP VENDOR</span>
				</div>
					
				<div class='field'>
					<label class='grey' for='pnpmodel'>PnP Model</label>
					<input type='text' id='pnpmodel' name='pnpmodel' value='<?php echo $pnpmodel ?>' maxlength='64'>
					<span class='information'>PNP MODEL</span>
				</div>
				
				<div class='field'>
					<label class='grey' for='pnpversion'>PnP Version</label>
					<input type='text' id='pnpversion' name='pnpversion' value='<?php echo $pnpversion ?>' maxlength='64'>
					<span class='information'>PNP VERSION</span>
				</div>
				</div>
				
				<div class="colRight">
				<?php 
					$selectStun = ($usestun === '1') ? 'selected' : '';
					$disabled = ($usestun === '0') ? 'disabled' : '';
				?>
				<div class='field'>
					<label class='grey' for='stun'>Use STUN</label>
					<select name='usestun' id='usestun'>
					<option value='0'>Disable STUN</value>
					<option value='1' <?php echo $selectStun ?> >Enable STUN</value>
					</select>
					<span class='information'>USE STUN SERVER</span>
				</div>
				
				<div class='field'>
					<label class='grey' for='stunaddr'>STUN Address</label>
					<input type='text' id='stunaddr' name='stunaddr' value='<?php echo $stunaddr ?>' maxlength='64' <?php echo $disabled ?>>
					<span class='information'>STUN SERVER ADDRESS</span>
				</div>
						
				<div class='field'>
					<label class='grey' for='stunport'>STUN Port</label>
					<input type='text' id='stunport' name='stunport' value='<?php echo $stunport ?>' maxlength='64' <?php echo $disabled ?>>
					<span class='information'>STUN SERVER PORT</span>
				</div>
				</div>
			
			</li>
			<!-- Second tab -->
			
			
			</li>
				<input type='hidden' id='selectedSystemName' name='selectedSystemName' value='<?php echo $selectedSystemName ?>'>
				<input type='hidden' id='selectedName' name='selectedName' value='<?php echo $selectedName ?>'>
				<input type='hidden' id='selectedGuid' name='selectedGuid' value='<?php echo $selectedGuid ?>'>
				<input type='hidden' id='selectedType' name='selectedType' value='<?php echo $selectedType ?>'>
				<input type='hidden' id='sipType' name='sipType' value='<?php echo $sipType ?>'>
				<input type='hidden' id='wanIP' name='wanIP' value='<?php echo $wanIP ?>'>
			</form>
			
			
			
			<div class='formFooter'>
				<div class='left' id='msg_wrap'>
					<span id='msg'></span>
				</div>
			
				<div class='right'>

					<input type='button' class='close' id ='close' value='Close'/>
					<input type='button' class='editEndpoint' id='editEndpoint' value='Save'/>
				</div>
			</div>

		</ul>
    </div>
	
</div>	
</body>
</html>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/managephones/popupEdit.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
</head>
<?php 
require('../assets/inc/ldapConnect.php');
require('load.php');
//$wanIP = (@file_get_contents("http://splicepbx.uk/ip.php")) ? @file_get_contents("http://splicepbx.uk/ip.php") : @file_get_contents("http://ipecho.net/plain") ;
$wanIP = (@file_get_contents("https://api.ipify.org")) ? @file_get_contents("https://api.ipify.org") : @file_get_contents("http://ipecho.net/plain");

if ($selectedType === '2'){
	$sslserver = $pcsserver = $showUpgrade = NULL;
	$sr = @ldap_read($ds,"cn=ssl,cn=system","objectclass=updateserver"); 
	if ($sr) { $info = ldap_get_entries($ds,$sr); $sslserver = $info[0]['url'][0]; }
	
	$sr = @ldap_read($ds,"cn=pcs,cn=system","objectclass=updateserver"); 
	if ($sr) { $info = ldap_get_entries($ds,$sr); $pcsserver = $info[0]['url'][0]; }
	
	if ($sslserver && $pcsserver) $showUpgrade = true;
}
?>
<body>
<!-- Element to pop up -->
<div style='background-color:#dddddd; border: 4px solid black; padding: 5px; height: 565px; width: 1015px;'>

<div id="wrapper">
        <ul id="tabs">
            <li class="active">Edit Phone</li>
			<?php  				
			if ($sipType == 'Yealink') 
				echo "<li>Provisioning</li>";
			?>

        </ul>
        <ul id="tab">
		<form id='popup'>
		<!-- first tab -->
            <li class="active">
                <h2><span id='FormIcon' class='icon-phone'></span> <span id='FormText'>Edit Phone: <?php echo "$selectedName - $sipType $typeofphone" ?></span></h2>
								
				<!-- #left -->
				<div class="colLeft">
				
				<!-- commonValues -->
					<div class='field'>
						<label class='grey' for="phoneName"><?php echo $phoneNameText ?></label>
						<input type='text' id='phoneName' name='phoneName' 
						<?php if ($sipType == 'Yealink') {
							echo "class='yealinkDevice' maxlength='12'"; 
							$phoneName = str_replace('SIP ','',$phoneName);
						}
						echo "value='$phoneName' $phoneNameState"; 
						?> 
						>
						<span class='information'><?php echo $phoneNameSpan ?></span>
					</div>
					
					<div class='field'>
						<label class='grey' for="description">Description</label>
						<input type='text' id='description' name='description' value='<?php echo $description ?>' >
						<span class='information'>PHONE DESCRIPTION</span>
					</div>
					
			<!-- commonValues -->

				<!-- potsPhone -->
				<?php if ($selectedType === '1') { ?>
					<div class='field'>
						<label class='grey' for="potCallerDisplayType">Caller Display Type</label>
						<select id='potCallerDisplayType' name='potCallerDisplayType'>
						<option value='0'  <?php if ($potCallerDisplayType === '0') echo 'selected' ?> >None</option>
						<option value='1'  <?php if ($potCallerDisplayType === '1') echo 'selected' ?> >Default</option>
						<option value='9'  <?php if ($potCallerDisplayType === '9') echo 'selected' ?> >Alarm</option>
						<option value='3'  <?php if ($potCallerDisplayType === '3') echo 'selected' ?> >Bell</option>
						<option value='2'  <?php if ($potCallerDisplayType === '2') echo 'selected' ?> >BT</option>
						<option value='5'  <?php if ($potCallerDisplayType === '5') echo 'selected' ?> >BT No Messages</option>
						<option value='4'  <?php if ($potCallerDisplayType === '4') echo 'selected' ?> >DTMF</option>
						<option value='15' <?php if ($potCallerDisplayType === '15') echo 'selected' ?> >Fax</option>
						<option value='7'  <?php if ($potCallerDisplayType === '7') echo 'selected' ?> >Fax Server</option>
						<option value='12' <?php if ($potCallerDisplayType === '12') echo 'selected' ?> >Lamp</option>
						<option value='8'  <?php if ($potCallerDisplayType === '8') echo 'selected' ?> >Interquartz</option>
						<option value='13' <?php if ($potCallerDisplayType === '13') echo 'selected' ?> >Pay Phone</option>
						<option value='10' <?php if ($potCallerDisplayType === '10') echo 'selected' ?> >PCS 10</option>
						<option value='11' <?php if ($potCallerDisplayType === '11') echo 'selected' ?> >PCS 10 Lamp</option>
						<option value='14' <?php if ($potCallerDisplayType === '14') echo 'selected' ?> >System Phone</option>
						<option value='6'  <?php if ($potCallerDisplayType === '6') echo 'selected' ?> >Trunk</option>
						<option value='16' <?php if ($potCallerDisplayType === '16') echo 'selected' ?> >BTD1K</option>
						<option value='17' <?php if ($potCallerDisplayType === '17') echo 'selected' ?> >DTMFR12</option>
						</select>
						<span class='information'>SPLICECOM POTS PORT CALLER DISPLAY TYPE</span>
					</div>
					<div class='field'>
						<label class='grey' for="potCallerDisplayLength">Caller Display Length</label>
						<input type='text' id='potCallerDisplayLength' name='potCallerDisplayLength' value='<?php echo $potCallerDisplayLength ?>'>
						<span class='information'>SPLICECOM POTS PORT CALLER DISPLAY LENGTH</span>
					</div>
				<?php } ?>
				<!-- potsPhone -->

				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
				
				<!-- pcsPhone -->
				<?php if ($selectedType === '2') { ?>
					<div class='field'>
						<label class='grey' for="pcsProductVersion">Device Product Version</label>
						<input type='text' id='pcsProductVersion' name='pcsProductVersion' value='<?php echo $productversion ?>' readonly>
						<span class='information'>SPLICECOM PCS IP PHONE PRODUCT VERSION</span>
					</div>					
					<div class='field'>
						<label class='grey' for="pcsPlc">Partner Login Code</label>
						<input type='text' id='pcsPlc' name='pcsPlc' value='<?php echo $pcsPlc ?>' >
						<span class='information'>SPLICECOM PCS IP PHONE PARTNER LOGIN CODE</span>
					</div>

					<?php 
					if ($showUpgrade) {
					?>
					<div class='field'>
						<label class='grey' for="pcsUpgrade">Upgrade Time</label>
						<input type='text' id='pcsUpgrade' name='pcsUpgrade' class='timepicker' value='' >
						<input type='hidden' id='pcsUpgradeTime' name='pcsUpgradeTime'value='<?php echo $pcsUpgrade ?>' disabled>
						<span class='information'>SPLICECOM PCS IP PHONE UPGRADE TIME</span>
					</div>										
					<?php
					}
					?>
					
					<div class='field'>
						<label class='grey' for="pcsExtnAnyWhere">Extension Anywhere</label>
						<input type='text' id='pcsExtnAnyWhere' name='pcsExtnAnyWhere' value='<?php echo $pcsExtnAnyWhere ?>' >
						<span class='information'>SPLICECOM PCS IP PHONE EXTENSION ANYWHERE</span>
					</div>										
				<?php } ?>
				<!-- pcsPhone -->
				
				
				
				<!-- potsPhone -->
				<?php if ($selectedType === '1') { ?>
				<div class='field'>
					<label class='grey' for="potPlc">Partner Login Code</label>
					<input type='text' id='potPlc' name='potPlc' value='<?php echo $potPlc ?>'>
					<span class='information'>SPLICECOM ANALOGUE PORT PARTNER LOGIN CODE</span>
				</div>		
				<div class='field'>
					<label class='grey' for="potsDTMF">Suppress DTMF</label>
					<div class='checkbox'><label for="potsDTMF"><div class="switch"><input type="checkbox" name='potsDTMF' id='potsDTMF' value="1" <?php if ($potsDTMF == "1") echo "checked" ?> />
					<div class="slider"></div></div></label></div>
					<span class='information'>SPLICECOM ANALOGUE PORT SUPPRESS DTMF</span>
				</div>					
				<div class='field'>
					<label class='grey' for="potExtnAnyWhere">Extension Anywhere</label>
					<input type='text' id='potExtnAnyWhere' name='potExtnAnyWhere' value='<?php echo $potExtnAnyWhere ?>'>
					<span class='information'>SPLICECOM ANALOGUE PORT EXTENSION ANYWHERE</span>
					</div>						
				<?php } ?>
				<!-- potsPhone -->
				
				<!-- genericPhone -->
				<?php if ($selectedType === '3') { ?>
					<div class='field'>
						<label class='grey' for="phoneProductVersion">Device Product Version</label>
						<input type='text' id='phoneProductVersion' name='phoneProductVersion' value='<?php echo $productversion ?>' readonly>
						<span class='information'>DEVICE PRODUCT VERSION</span>
					</div>					
					<div class='field'>
						<label class='grey' for="phoneIPAddress">Device IP Address</label>
						<input type='text' id='phoneIPAddress' name='phoneIPAddress' value='<?php echo $phoneIPAddress ?>'>
						<span class='information'>DEVICE IP ADDRESS</span>
					</div>
				<?php if ($sipType == "Yealink") { ?>
					<div class='field'>
						<label class='grey' for='siplicense'>SIP Phone Licence</label>
						<div class='checkbox'><label for="siplicense"><div class="switch"><input type="checkbox" name='siplicense' id='siplicense' value="1" <?php if ($siplicense == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>ENABLE SIP PHONE LICENCE</span>
					</div>	
				
				<?php
						}
					}
				?>
				<!-- genericPhone -->
				
					
				</div> 
				<!-- #right -->
			</li>	
			<!-- first tab -->
			
			<!-- Second tab -->
			<li>
                <h2><span id='FormIcon' class='icon-phone'></span> <span id='FormText'>Edit Phone: <?php echo "$selectedName - $sipType $typeofphone" ?></span></h2>
								
				<!-- #left -->
				<div class="colLeft">
				<div class='field'>
					<label class='grey' for='pnpvendor'>PnP Vendor</label>
					<input type='text' id='pnpvendor' name='pnpvendor' value='<?php echo $pnpvendor ?>' maxlength='64'>
					<span class='information'>PNP VENDOR</span>
				</div>
					
				<div class='field'>
					<label class='grey' for='pnpmodel'>PnP Model</label>
					<input type='text' id='pnpmodel' name='pnpmodel' value='<?php echo $pnpmodel ?>' maxlength='64'>
					<span class='information'>PNP MODEL</span>
				</div>
				
				<div class='field'>
					<label class='grey' for='pnpversion'>PnP Version</label>
					<input type='text' id='pnpversion' name='pnpversion' value='<?php echo $pnpversion ?>' maxlength='64'>
					<span class='information'>PNP VERSION</span>
				</div>
				</div>
				
				<div class="colRight">
				<?php 
					$selectStun = ($usestun === '1') ? 'selected' : '';
					$disabled = ($usestun === '0') ? 'disabled' : '';
				?>
				<div class='field'>
					<label class='grey' for='stun'>Use STUN</label>
					<select name='usestun' id='usestun'>
					<option value='0'>Disable STUN</value>
					<option value='1' <?php echo $selectStun ?> >Enable STUN</value>
					</select>
					<span class='information'>USE STUN SERVER</span>
				</div>
				
				<div class='field'>
					<label class='grey' for='stunaddr'>STUN Address</label>
					<input type='text' id='stunaddr' name='stunaddr' value='<?php echo $stunaddr ?>' maxlength='64' <?php echo $disabled ?>>
					<span class='information'>STUN SERVER ADDRESS</span>
				</div>
						
				<div class='field'>
					<label class='grey' for='stunport'>STUN Port</label>
					<input type='text' id='stunport' name='stunport' value='<?php echo $stunport ?>' maxlength='64' <?php echo $disabled ?>>
					<span class='information'>STUN SERVER PORT</span>
				</div>
				</div>
			
			</li>
			<!-- Second tab -->
			
			
			</li>
				<input type='hidden' id='selectedSystemName' name='selectedSystemName' value='<?php echo $selectedSystemName ?>'>
				<input type='hidden' id='selectedName' name='selectedName' value='<?php echo $selectedName ?>'>
				<input type='hidden' id='selectedGuid' name='selectedGuid' value='<?php echo $selectedGuid ?>'>
				<input type='hidden' id='selectedType' name='selectedType' value='<?php echo $selectedType ?>'>
				<input type='hidden' id='sipType' name='sipType' value='<?php echo $sipType ?>'>
				<input type='hidden' id='wanIP' name='wanIP' value='<?php echo $wanIP ?>'>
			</form>
			
			
			
			<div class='formFooter'>
				<div class='left' id='msg_wrap'>
					<span id='msg'></span>
				</div>
			
				<div class='right'>

					<input type='button' class='close' id ='close' value='Close'/>
					<input type='button' class='editEndpoint' id='editEndpoint' value='Save'/>
				</div>
			</div>

		</ul>
    </div>
	
</div>	
</body>
</html>
